@@ -237,6 +237,10 @@ class Cache(Expression):
     }
 
 
+class Command(Expression):
+    arg_types = {"this": True, "expression": False}
+
+
 class Create(Expression):
     arg_types = {
         "this": True,
@@ -319,6 +323,10 @@ class Group(Expression):
     arg_types = {"expressions": True}
 
 
+class Lambda(Expression):
+    arg_types = {"this": True, "expressions": True}
+
+
 class Limit(Expression):
     pass
 
@@ -748,6 +756,11 @@ class Coalesce(Func):
     is_var_len_args = True
 
 
+class ConcatWs(Func):
+    arg_types = {"expressions": False}
+    is_var_len_args = True
+
+
 class Count(AggFunc):
     arg_types = {"this": False, "distinct": False}
 
