@@ -127,6 +127,13 @@ class Generator:
         self.pretty = original
         return result
 
+    def no_identify(self, func):
+        original = self.identify
+        self.identify = False
+        result = func()
+        self.identify = original
+        return result
+
     def indent_newlines(self, sql, skip_first=False):
         if not self.pretty:
             return sql
@@ -350,6 +357,11 @@ class Generator:
         this_sql = self.sql(expression, "this")
         return f"{expression_sql}{op_sql} {this_sql}{on_sql}"
 
+    def lambda_sql(self, expression):
+        return self.no_identify(
+            lambda: f"({self.expressions(expression, flat=True)}) -> {self.sql(expression, 'this')}"
+        )
+
     def lateral_sql(self, expression):
         this = self.sql(expression, "this")
         op_sql = self.seg(
@@ -561,6 +573,9 @@ class Generator:
     def cast_sql(self, expression):
         return f"CAST({self.sql(expression, 'this')} AS {self.sql(expression, 'to')})"
 
+    def command_sql(self, expression):
+        return f"{self.sql(expression, 'this').upper()} {expression.text('expression').strip()}"
+
     def count_sql(self, expression):
         distinct = "DISTINCT " if expression.args["distinct"] else ""
         return f"COUNT({distinct}{self.sql(expression, 'this')})"
